==> haskell-universe-base-1.1.2-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 universe-base
version:              1.1.2
visibility:           public
id:                   universe-base-1.1.2-6XrvqQNiWlvLn7tlzQ26Wf
key:                  universe-base-1.1.2-6XrvqQNiWlvLn7tlzQ26Wf
license:              BSD-3-Clause
copyright:            2014 Daniel Wagner
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:             A class for finite and recursively enumerable types.
description:
    A class for finite and recursively enumerable types and some helper functions for enumerating them.

    @
    class Universe a where universe :: [a]
    class Universe a => Finite a where universeF :: [a]; universeF = universe
    @

    This is slim package definiting only the type-classes and instances
    for types in GHC boot libraries.
    For more instances check @universe-instances-*@ packages.

category:             Data
abi:                  3b151e3d33829d821875aaa2bb22a769
exposed:              True
exposed-modules:
    Data.Universe.Class Data.Universe.Generic Data.Universe.Helpers

import-dirs:          /usr/lib/ghc-8.10.4/site-local/universe-base-1.1.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/universe-base-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/universe-base-1.1.2
hs-libraries:         HSuniverse-base-1.1.2-6XrvqQNiWlvLn7tlzQ26Wf
depends:
    base-4.14.1.0 containers-0.6.2.1
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-universe-base/html/universe-base.haddock

haddock-html:         /usr/share/doc/haskell-universe-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-universe-base-1.1.2-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 universe-base
version:              1.1.2
visibility:           public
id:                   universe-base-1.1.2-I565XrsMBwAKOzFXUVac2u
key:                  universe-base-1.1.2-I565XrsMBwAKOzFXUVac2u
license:              BSD-3-Clause
copyright:            2014 Daniel Wagner
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:             A class for finite and recursively enumerable types.
description:
    A class for finite and recursively enumerable types and some helper functions for enumerating them.

    @
    class Universe a where universe :: [a]
    class Universe a => Finite a where universeF :: [a]; universeF = universe
    @

    This is slim package definiting only the type-classes and instances
    for types in GHC boot libraries.
    For more instances check @universe-instances-*@ packages.

category:             Data
abi:                  22d32dabac8d11f9ea0f1ba109ce61e6
exposed:              True
exposed-modules:
    Data.Universe.Class Data.Universe.Generic Data.Universe.Helpers

import-dirs:          /usr/lib/ghc-8.10.4/site-local/universe-base-1.1.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/universe-base-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/universe-base-1.1.2
hs-libraries:         HSuniverse-base-1.1.2-I565XrsMBwAKOzFXUVac2u
depends:
    base-4.14.1.0 containers-0.6.2.1
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-universe-base/html/universe-base.haddock

haddock-html:         /usr/share/doc/haskell-universe-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
